import { Component, Input, OnInit, EventEmitter, ViewChildren, QueryList } from "@angular/core";
import { ICheckDirective } from "../../directives/icheck.directive";
import * as _ from "lodash";
var ListFilterComponent = /** @class */ (function () {
    function ListFilterComponent() {
        this.title = "";
        this.name = "";
        this.items = [];
        this.displayName = "label";
        this.value = "value";
        this.checkedItems = {};
        this.itemsActive = 0;
        this.menuShown = false;
    }
    ListFilterComponent.prototype.ngOnInit = function () {
        var _this = this;
        // If data is specified and items is empty fetch and fill.
        if (this.dataService) {
            this.dataService
                .fetchAll()
                .subscribe(function (data) {
                _this.items = data.payload;
            });
        }
    };
    ListFilterComponent.prototype.reset = function () {
        this.itemsActive = 0;
        this.checkedItems = {};
        this.checkboxes.forEach(function (item) {
            item.unCheck();
        });
    };
    /**
     * When a filter is made active or deactivated.
     *
     * @param name The name of the item.
     * @param event The filter returned.
     */
    /**
         * When a filter is made active or deactivated.
         *
         * @param name The name of the item.
         * @param event The filter returned.
         */
    ListFilterComponent.prototype.rowChecked = /**
         * When a filter is made active or deactivated.
         *
         * @param name The name of the item.
         * @param event The filter returned.
         */
    function (name, event) {
        var _this = this;
        this.checkedItems[name] = event;
        clearTimeout(this.timeout);
        this.timeout = setTimeout(function () {
            var value = Object.keys(_.pickBy(_this.checkedItems, function (value, key) {
                return value;
            }));
            _this.filterEmitter.emit({
                name: _this.name,
                value: value,
                operator: "IN"
            });
            _this.itemsActive = value.length;
        }, 1000);
    };
    ListFilterComponent.prototype.toggleClickMenu = function (e) {
        e.stopPropagation();
        e.preventDefault();
        this.menuShown = !this.menuShown;
    };
    ListFilterComponent.prototype.closeMenu = function (e) {
        this.menuShown = false;
    };
    ListFilterComponent.prototype.showDropDown = function () {
        return this.menuShown ? "block" : "hide";
    };
    ListFilterComponent.decorators = [
        { type: Component, args: [{
                    selector: "c-list-filter",
                    template: '<span dropdown> <button type="button" class="btn btn-default dropdown-toggle" dropdownToggle> <span>{{title}}</span> <span *ngIf="itemsActive > 0"> ({{itemsActive}}) </span> <span class="caret"></span> </button> <ul class="dropdown-menu" *dropdownMenu> <li *ngFor="let item of items"> <a> <label> <input type="checkbox" [icheck]="false" (icheckChange)="rowChecked(item[value], $event)" /> {{item[displayName]}} </label> </a> </li> </ul> </span> '
                },] },
    ];
    /** @nocollapse */
    ListFilterComponent.ctorParameters = function () { return []; };
    ListFilterComponent.propDecorators = {
        "title": [{ type: Input },],
        "name": [{ type: Input },],
        "items": [{ type: Input },],
        "displayName": [{ type: Input },],
        "value": [{ type: Input },],
        "dataService": [{ type: Input },],
        "checkedItems": [{ type: Input },],
        "filterEmitter": [{ type: Input },],
        "checkboxes": [{ type: ViewChildren, args: [ICheckDirective,] },],
    };
    return ListFilterComponent;
}());
export { ListFilterComponent };
//# sourceMappingURL=list.filter.component.js.map