import { EventEmitter, AfterContentInit } from "@angular/core";
import { QueryList, OnInit } from "@angular/core";
import { Observable } from "rxjs/Observable";
import { ApiFilterInterface } from "../../interfaces/api-filter.interface";
import { PaginationComponent } from "../pagination/pagination.component";
import { SearchComponent } from "../search/search.component";
import { CounterComponent } from "../counter/counter.component";
import { ListRowComponent } from "../list-row/list.row.component";
import { ListPreviewComponent } from "../list-preview/list.preview.component";
import { NotFoundComponent } from "../not-found/not.found.component";
import { NoResultsComponent } from "../no-results/no.results.component";
import { ClearFiltersComponent } from "../clear-filters/clear.filters.component";
import { ShowMoreComponent } from "../show-more/show.more.component";
import { ListFilterComponent } from "../list-filter/list.filter.component";
import { DateFilterComponent } from "../date-filter/date.filter.component";
import { Subscription } from "rxjs/Subscription";
/**
 * This component is a container for managing list view components together.
 * Its purpose is to manage and disperse data from a single location making management easier.
 *
 * Basic Example Usage
 * -------------
 *
 * Component TS
 *
 * @Component({
 *    selector: 'c-my-component',
 *    template: `
 *        <c-list-view #list [dataService]="userService">
 *          <c-pagination></c-pagination>
 *          <div *ngFor="let row of list.rows">
 *            {{row.firstName}}
 *          </div>
 *        </c-list-view>
 *    `,
 *
 * })
 * class MyComponent {
 *     constructor(public userService: UserService) {}
 * }
 *
 */
export declare class ListViewComponent implements OnInit, AfterContentInit {
    dataService: {
        getFilters: () => Array<any>;
        setParam: (name: string, filters: any) => any;
        primaryKey: () => string;
    };
    changePageEmitter: EventEmitter<{}>;
    searchTerm: EventEmitter<{}>;
    filtersEmitter: EventEmitter<{}>;
    filterEmitter: EventEmitter<{}>;
    clearFiltersEmitter: EventEmitter<{}>;
    listPreviewVisibleEmitter: EventEmitter<{}>;
    activeRowEmitter: EventEmitter<{}>;
    loadMoreEmitter: EventEmitter<{}>;
    pageChangeScrollTop: boolean;
    handleRequestErrorEmitter: EventEmitter<{}>;
    filters: Array<ApiFilterInterface>;
    currentPage: number;
    loading: boolean;
    pageCount: number;
    meta: {};
    rows: Array<any>;
    activeRow: any;
    previewHidden: boolean;
    contentHandle: Subscription;
    counterComponents: QueryList<CounterComponent>;
    searchComponent: SearchComponent;
    listRowComponent: ListRowComponent;
    paginationComponent: QueryList<PaginationComponent>;
    notFoundComponent: NotFoundComponent;
    noResultsComponent: NoResultsComponent;
    clearFiltersComponent: QueryList<ClearFiltersComponent>;
    listFiltersComponent: QueryList<ListFilterComponent>;
    dateFiltersComponent: QueryList<DateFilterComponent>;
    listPreviewComponent: ListPreviewComponent;
    showMoreComponent: ShowMoreComponent;
    originalFilters: Array<ApiFilterInterface>;
    dataSource: Observable<any>;
    lastSearch: string;
    updating: boolean;
    activeID: number;
    /**
     * @inheritdoc
     */
    ngOnInit(): void;
    /**
     * Resets the page index back to zero.
     *
     * @param withRefresh whether to refresh or wait.
     */
    resetPageIndex(withRefresh?: boolean): void;
    /**
     * @inheritdoc
     */
    ngAfterContentInit(): void;
    /**
     * Refreshes the list.
     */
    refresh(hidePreview?: boolean): Promise<{}>;
    /**
     * Changes all filters.
     *
     * @param filters
     */
    replaceFilters(filters: Array<ApiFilterInterface>): void;
    /**
     * Resets the data source back to default with filters if defined.
     *
     * @param {Array<ApiFilterInterface>} filters
     */
    resetDataSource(filters?: Array<ApiFilterInterface>): void;
    /**
     * Makes sure that filter is unique. Updates existing if already exists.
     *
     * @param filter
     */
    applyUniqueFilter(filter: ApiFilterInterface): void;
    /**
     * Applys filters and update subscriptions.
     */
    applyFilters(append?: boolean): void;
    /**
     * Clears all filters stored against this list view.
     *
     * @param clear
     */
    clearFilters(clear: boolean): void;
    /**
     * Syncs all data to child components
     */
    updateSubscriptions(append?: boolean, hidePreview?: boolean): Promise<{}>;
    /**
     * Initiates SearchComponent sub component.
     */
    initSearchComponent(): void;
    /**
     * Initiates ListRowComponent sub component.
     */
    initListRowComponent(data: any, append?: Boolean): void;
    /**
     * Initiates PaginationComponent sub component.
     */
    initPaginationComponent(data: any): void;
    /**
     * Initiates CounterComponent sub component.
     */
    initCounterComponent(data: any): void;
    /**
     * Checks if the current list has been filtered in any way.
     * @returns {boolean}
     */
    isFiltered(): boolean;
    /**
     * Initiates NotFoundComponent sub component.
     */
    initNotFoundComponent(data: any): void;
    /**
     * Initiates NoResultsComponent sub component.
     */
    initNoResultsComponent(data: any): void;
    /**
     * Initiates ClearFiltersComponent sub component.
     */
    initClearFiltersComponent(): void;
    /**
     * Initiates ListFiltersComponent sub component.
     */
    initListFiltersComponent(): void;
    /**
     * Initiates DateFiltersComponent sub component.
     */
    initDateFiltersComponent(): void;
    /**
     * Initiates ListPreviewComponent sub component.
     */
    initListPreviewComponent(hidePreview?: boolean): void;
    /**
     * Initiate Show more sub component.
     *
     * @param data
     */
    initShowMoreComponent(data: any): void;
    /**
     * Toggles the visibility of the list preview component.
     */
    togglePreviewVisibility(): void;
    /**
     * Sets the current row as active.
     *
     * @param row
     * @param {Event} event
     * @return {boolean}
     */
    setActiveRow(row: any, event?: Event): boolean;
    /**
     * Checks if the current row is the active one.
     *
     * @param row
     * @returns {boolean}
     */
    isActiveRow(row: any): boolean;
    /**
     * Checks if the preview is hidden.
     *
     * @returns {boolean}
     */
    isPreviewHidden(): boolean;
}
