import { Component, Input, OnChanges } from "@angular/core";
import { EventEmitter } from "@angular/core";
var PaginationComponent = /** @class */ (function () {
    function PaginationComponent() {
        this.type = 'buttons';
        this.page = 1;
        this.pageCount = 1;
        this.pages = [];
        this.updating = false;
    }
    PaginationComponent.prototype.ngOnChanges = function (changes) {
        this.pages = this.updatePagination();
    };
    PaginationComponent.prototype.onPrev = function () {
        this.goToPage(this.page - 1);
    };
    PaginationComponent.prototype.onNext = function () {
        this.goToPage(this.page + 1);
    };
    PaginationComponent.prototype.goToPage = function (page) {
        this.updating = true;
        this.changePageEmitter.emit(page);
    };
    PaginationComponent.prototype.updatePagination = function () {
        this.updating = false;
        var pagesArray = [];
        var currentPage = this.page;
        var pagesCount = this.pageCount;
        if (this.type === 'buttons') {
            var paginationSpan = 2;
            var startPos = 2;
            var endPos = startPos + paginationSpan - 1;
            var middlePos = Math.ceil(paginationSpan / 2);
            // Adjust start and end positions to maintain range and keep current page as active.
            if (currentPage >= startPos + 1) {
                startPos = currentPage - middlePos + 1;
                endPos = startPos + paginationSpan - 1;
                if (endPos + 1 > pagesCount) {
                    startPos = pagesCount - paginationSpan;
                    endPos = pagesCount - 1;
                }
            }
            /*
                         * Extra adjustments in case pagination range is larger than results.
                         */
            if (startPos < 2) {
                startPos = 2;
            }
            if (endPos >= pagesCount) {
                endPos = pagesCount - 1;
            }
            if (endPos < startPos) {
                endPos = startPos - 1;
            }
            // Only show pagination when there is more than one page.
            if (pagesCount > 1) {
                /*
                                 * Create pagination range.
                                 */
                pagesArray.push({
                    value: 1,
                    isPage: true,
                    active: +currentPage === 1,
                    disabled: false
                });
                if (startPos > 2) {
                    pagesArray.push({ value: "...", isPage: false, active: false, disabled: true });
                }
                for (var i = startPos; i <= endPos; i++) {
                    pagesArray.push({
                        value: i,
                        isPage: true,
                        active: i === +currentPage,
                        disabled: false
                    });
                }
                if (endPos + 1 !== +pagesCount) {
                    pagesArray.push({ value: "...", isPage: false, active: false, disabled: true });
                }
                pagesArray.push({
                    value: pagesCount,
                    isPage: true,
                    active: +pagesCount === +currentPage,
                    disabled: false
                });
            }
        }
        else {
            for (var i = 1; i <= this.pageCount; i++) {
                pagesArray.push(i);
            }
        }
        return pagesArray;
    };
    PaginationComponent.decorators = [
        { type: Component, args: [{
                    selector: "c-pagination",
                    template: '<ng-template [ngIf]="type === \'buttons\'"> <nav *ngIf="pages.length > 1"> <div class="btn-group m-r-sm"> <button type="button" class="btn btn-white" (click)="onPrev()"> <i class="fa fa-chevron-left"></i> </button> <button *ngFor="let page of pages" class="btn btn-white" [ngClass]="{active: page.active}" (click)="goToPage(page.value)"> {{page.value}} </button> <button type="button" class="btn btn-white" (click)="onNext()"> <i class="fa fa-chevron-right"></i> </button> </div> </nav> </ng-template> <ng-template [ngIf]="type !== \'buttons\' && pages.length > 1"> <ng-content></ng-content> <select [(ngModel)]="page" (ngModelChange)="goToPage($event)"> <option *ngFor="let current of pages" [value]="current">{{current}}</option> </select> </ng-template> '
                },] },
    ];
    /** @nocollapse */
    PaginationComponent.ctorParameters = function () { return []; };
    PaginationComponent.propDecorators = {
        "type": [{ type: Input },],
        "page": [{ type: Input },],
        "pageCount": [{ type: Input },],
        "changePageEmitter": [{ type: Input },],
    };
    return PaginationComponent;
}());
export { PaginationComponent };
//# sourceMappingURL=pagination.component.js.map