import { Component, Input, OnInit, EventEmitter, Output } from "@angular/core";
import { FormControl } from "@angular/forms";
import "rxjs/add/operator/debounceTime";
var SearchComponent = /** @class */ (function () {
    function SearchComponent() {
        this.searchTerm = new EventEmitter();
        this.placeholder = "Search";
        this.debounceTime = 500;
        this.isCustom = false;
        this.classes = ["form-control"];
        this.searchInputControl = new FormControl();
    }
    SearchComponent.prototype.ngOnInit = function () {
        var _this = this;
        // Subscribe to and debounce form control, emitting search results
        this.searchInputControl
            .valueChanges
            .debounceTime(this.debounceTime)
            .subscribe(function (term) {
            _this.searchInputControl.setValue(term, { emitEvent: false });
            if (_this.target) {
                _this.target.searchTerm.emit(term);
            }
            else {
                _this.searchTerm.emit(term);
            }
        });
    };
    SearchComponent.prototype.clearSearchTerm = function (emit) {
        if (emit === void 0) { emit = false; }
        this.searchInputControl.setValue("", { emitEvent: emit });
    };
    SearchComponent.decorators = [
        { type: Component, args: [{
                    selector: "c-search",
                    template: '<ng-template [ngIf]="isCustom"> <ng-content></ng-content> </ng-template> <ng-template [ngIf]="!isCustom"> <div class="form-group"> <a (click)="clearSearchTerm(true)" class="search-clear"> <i class="fa fa-times fa-1x"></i> </a> <input type="text" [ngClass]="classes" placeholder="Search" [formControl]="searchInputControl" /> </div> </ng-template> ',
                    styles: ["\n        :host {\n            position: relative;\n            display: block;\n        }\n        .search-clear {\n            position: absolute;\n            top: 7px;\n            right: 8px;\n        }\n        a {\n            cursor: pointer;\n        }\n    "]
                },] },
    ];
    /** @nocollapse */
    SearchComponent.ctorParameters = function () { return []; };
    SearchComponent.propDecorators = {
        "searchTerm": [{ type: Output }, { type: Input },],
        "placeholder": [{ type: Input },],
        "debounceTime": [{ type: Input },],
        "isCustom": [{ type: Input },],
        "target": [{ type: Input },],
    };
    return SearchComponent;
}());
export { SearchComponent };
//# sourceMappingURL=search.component.js.map